LRB Search Results

| Slip Decisions Search Results
Search Criteria
Decision Start Date : 01/01/2005
Decision End Date : 02/01/2005
Court : Appellate Term, 2d Dept
Total number of records found: 36
Party Name | Decision Date | Court | Official Citation | Slip Number | Judge | Opn/Mot
A.B. Med. Servs. PLLC v Motor Veh. Acc. Indem. Corp. | 02/01/2005 | Appellate Term, 2d Dept | 6 Misc 3d 131(A) | 2005 NYSlipOp 50088(U) |  | Opinion
A.B. Med. Servs. PLLC v Prudential Prop. & Cas. Ins. Co. | 01/20/2005 | Appellate Term, 2d Dept | 7 Misc 3d 14 | 2005 NYSlipOp 25032 |  | Opinion
A.B. Med. Servs. PLLC v Prudential Prop. & Cas. Ins. Co. | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50076(U) |  | Opinion
Allied Bldrs. v Banjoku | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50075(U) |  | Opinion
Amaze Med. Supply Inc. v Liberty Mut. Ins. Co. | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 131(A) | 2005 NYSlipOp 50083(U) |  | Opinion
Amaze Med. Supply Inc. v Lumbermens Mut. Cas. Co. | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 131(A) | 2005 NYSlipOp 50084(U) |  | Opinion
Bloom v Gea Eng'g PC | 01/20/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50073(U) |  | Opinion
Browne v Leino | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 131(A) | 2005 NYSlipOp 50079(U) |  | Opinion
Carr v Ruffino | 01/20/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50071(U) |  | Opinion
Colorito v Crown Heating & Cooling, Inc. | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 131(A) | 2005 NYSlipOp 50082(U) |  | Opinion
Gobaira v Castillo | 01/20/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50068(U) |  | Opinion
Gonzalez v Abraham Jaro Realty Corp. | 01/20/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50069(U) |  | Opinion
Jacome v Singh | 01/27/2005 | Appellate Term, 2d Dept | 7 Misc 3d 40 | 2005 NYSlipOp 25033 |  | Opinion
Mennella v Madonia | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50074(U) |  | Opinion
Ocean Diagnostic Imaging, Inc. v Utica Mut. Ins. Co. | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 131(A) | 2005 NYSlipOp 50081(U) |  | Opinion
Osborne v Moutafis | 01/27/2005 | Appellate Term, 2d Dept | 7 Misc 3d 32 | 2005 NYSlipOp 25034 |  | Opinion
People v CAMPBELL (BRIAN) | 01/26/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50064(U) |  | Opinion
People v COLLADO (ARTURO) | 01/26/2005 | Appellate Term, 2d Dept | 7 Misc 3d 35 | 2005 NYSlipOp 25030 |  | Opinion
People v GREER (RALPH) | 01/26/2005 | Appellate Term, 2d Dept | 6 Misc 3d 129(A) | 2005 NYSlipOp 50062(U) |  | Opinion
People v GUILIANO (MICHAEL) | 01/26/2005 | Appellate Term, 2d Dept | 6 Misc 3d 129(A) | 2005 NYSlipOp 50061(U) |  | Opinion
People v JONES (NYISHA) | 01/26/2005 | Appellate Term, 2d Dept | 6 Misc 3d 129(A) | 2005 NYSlipOp 50063(U) |  | Opinion
People v KALWISS (MICHAEL) | 01/26/2005 | Appellate Term, 2d Dept | 6 Misc 3d 129(A) | 2005 NYSlipOp 50057(U) |  | Opinion
People v KRANTZ (JEROME) | 01/26/2005 | Appellate Term, 2d Dept | 6 Misc 3d 129(A) | 2005 NYSlipOp 50058(U) |  | Opinion
People v LABERTA (LAURA) | 01/26/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50066(U) |  | Opinion
People v OHBERG (MARK) | 01/26/2005 | Appellate Term, 2d Dept | 6 Misc 3d 129(A) | 2005 NYSlipOp 50060(U) |  | Opinion
People v RICHARD S. | 01/26/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50065(U) |  | Opinion
People v RODRIGUES (JOSE) | 01/26/2005 | Appellate Term, 2d Dept | 6 Misc 3d 129(A) | 2005 NYSlipOp 50059(U) |  | Opinion
People v SYLLA (MAURICE) | 01/26/2005 | Appellate Term, 2d Dept | 7 Misc 3d 8 | 2005 NYSlipOp 25031 |  | Opinion
Power Brake Serv. Inc. v Hylan Elec. Contr. Inc. | 02/01/2005 | Appellate Term, 2d Dept | 6 Misc 3d 131(A) | 2005 NYSlipOp 50086(U) |  | Opinion
Ray Russell & Son v Murphy | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 131(A) | 2005 NYSlipOp 50078(U) |  | Opinion
Sosinsky, Rodis & Stein v Ravens | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50077(U) |  | Opinion
Tischler v Aber | 02/01/2005 | Appellate Term, 2d Dept | 6 Misc 3d 131(A) | 2005 NYSlipOp 50087(U) |  | Opinion
Urena v Good Home Realty, Inc. | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 131(A) | 2005 NYSlipOp 50085(U) |  | Opinion
Vilmont v Kenyon LLC | 01/20/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50072(U) |  | Opinion
Woodson v Long Is. R.R. | 01/27/2005 | Appellate Term, 2d Dept | 6 Misc 3d 131(A) | 2005 NYSlipOp 50080(U) |  | Opinion
Xerox Corp. v Stewart | 01/20/2005 | Appellate Term, 2d Dept | 6 Misc 3d 130(A) | 2005 NYSlipOp 50070(U) |  | Opinion